package com.jiuqi.dna.ide.designer.parts;

import com.jiuqi.dna.ide.designer.DesignerMessages;
import com.jiuqi.dna.ide.designer.connection.IConnectionProvider;
import com.jiuqi.dna.ide.designer.elements.BendpointElement;
import com.jiuqi.dna.ide.designer.elements.IBendpointElement;
import com.jiuqi.dna.ide.designer.elements.ILinkElement;
import com.jiuqi.dna.ide.designer.elements.LinkElement;
import com.jiuqi.dna.ide.designer.events.BendpointAdapter;
import com.jiuqi.dna.ide.designer.events.BendpointEvent;
import com.jiuqi.dna.ide.designer.events.IBendpointListener;
import com.jiuqi.dna.ide.designer.policies.LinkBendpointEditPolicy;
import com.jiuqi.dna.ide.designer.policies.LinkElementEditPolicy;
import com.jiuqi.dna.ide.designer.policies.LinkEndpointEditPolicy;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.ArrayList;
import java.util.List;
import org.eclipse.draw2d.Connection;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.AccessibleEditPart;
import org.eclipse.gef.editparts.AbstractConnectionEditPart;
import org.eclipse.gef.editparts.AbstractGraphicalEditPart;
import org.eclipse.swt.accessibility.AccessibleEvent;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.widgets.Display;

/* loaded from: com_jiuqi_dna_ide_designer_parts.jar:com/jiuqi/dna/ide/designer/parts/LinkEditPart.class */
public class LinkEditPart extends AbstractConnectionEditPart implements PropertyChangeListener {
    public static final Color alive = new Color(Display.getDefault(), 0, 74, 168);
    public static final Color dead = new Color(Display.getDefault(), 0, 0, 0);
    private AccessibleEditPart acc;
    private IConnectionProvider connectionProvider;
    private IBendpointListener bendpointListener = new BendpointAdapter() { // from class: com.jiuqi.dna.ide.designer.parts.LinkEditPart.1
        public void bendpointCreate(BendpointEvent event) {
            if (event.link == LinkEditPart.this.getCastedModel()) {
                LinkEditPart.this.refreshBendpoints();
            }
        }

        public void bendpointDelete(BendpointEvent event) {
            if (event.link == LinkEditPart.this.getCastedModel()) {
                LinkEditPart.this.refreshBendpoints();
            }
        }

        public void bendpointMove(BendpointEvent event) {
            if (event.link == LinkEditPart.this.getCastedModel()) {
                LinkEditPart.this.refreshBendpoints();
            }
        }
    };

    public void activate() {
        super.activate();
        LinkElement castedModel = getCastedModel();
        if (castedModel instanceof LinkElement) {
            castedModel.getDesigner().addBendpointListener(this.bendpointListener);
        }
    }

    public void activateFigure() {
        super.activateFigure();
        getFigure().addPropertyChangeListener("connectionRouter", this);
    }

    public void deactivate() {
        super.deactivate();
        LinkElement castedModel = getCastedModel();
        if (castedModel instanceof LinkElement) {
            castedModel.getDesigner().removeBendpointListener(this.bendpointListener);
        }
    }

    public void deactivateFigure() {
        getFigure().removePropertyChangeListener("connectionRouter", this);
        super.deactivateFigure();
    }

    protected void createEditPolicies() {
        installEditPolicy("Connection Endpoint Policy", new LinkEndpointEditPolicy());
        installEditPolicy("Connection Bendpoint Policy", new LinkBendpointEditPolicy());
        installEditPolicy("ConnectionEditPolicy", new LinkElementEditPolicy());
    }

    protected IFigure createFigure() {
        Connection connx = this.connectionProvider.getConnection(getCastedModel());
        return connx;
    }

    public AccessibleEditPart getAccessibleEditPart() {
        if (this.acc == null) {
            this.acc = new AbstractGraphicalEditPart.AccessibleGraphicalEditPart(this) { // from class: com.jiuqi.dna.ide.designer.parts.LinkEditPart.2
                public void getName(AccessibleEvent e) {
                    e.result = DesignerMessages.WorkflowDesigner_Link_LabelText;
                }
            };
        }
        return this.acc;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public ILinkElement getCastedModel() {
        return (ILinkElement) getModel();
    }

    @Override // java.beans.PropertyChangeListener
    public void propertyChange(PropertyChangeEvent event) {
        String property = event.getPropertyName();
        if ("connectionRouter".equals(property)) {
            refreshBendpoints();
        }
    }

    protected void refreshBendpoints() {
        List<Point> modelConstraint = getCastedModel().getBendpoints();
        List<IBendpointElement> figureConstraint = new ArrayList<>();
        for (int i = 0; i < modelConstraint.size(); i++) {
            Point point = modelConstraint.get(i);
            figureConstraint.add(new BendpointElement(i, point));
        }
        getConnectionFigure().setRoutingConstraint(figureConstraint);
    }

    protected void refreshVisuals() {
        refreshBendpoints();
        if (getCastedModel().isVisible()) {
            getFigure().setForegroundColor(alive);
        } else {
            getFigure().setForegroundColor(dead);
        }
    }

    public void setConnectionProvider(IConnectionProvider connectionProvider) {
        this.connectionProvider = connectionProvider;
    }

    public Connection getConnectionFigure() {
        return super.getConnectionFigure();
    }
}
